==> SimpleMailer-1.02.tar.bz2: SimpleMailer-1.02/core/Smdn.Net.Pop3.Client/Smdn.Net.Pop3.Client/PopClient.OperationsDownload.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2010-2014 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;
using System.Linq;
using System.IO;
using System.Text;

namespace Smdn.Net.Pop3.Client {
  partial class PopClient {
    public string DownloadMessageAsText(long messageNumber, Encoding encoding)
    {
      return GetMessage(messageNumber).ReadAllText(encoding);
    }

    public string DownloadFirstMessageAsText(Encoding encoding)
    {
      return GetFirstMessage().ReadAllText(encoding);
    }

    public string DownloadLastMessageAsText(Encoding encoding)
    {
      return GetLastMessage().ReadAllText(encoding);
    }

    public IEnumerable<string> DownloadAllMessagesAsText(Encoding encoding)
    {
      foreach (var message in GetMessages(false)) {
        yield return message.ReadAllText(encoding);
      }
    }

    public byte[] DownloadMessageAsByteArray(long messageNumber)
    {
      return GetMessage(messageNumber).ReadAllBytes();
    }

    public byte[] DownloadFirstMessageAsByteArray()
    {
      return GetFirstMessage().ReadAllBytes();
    }

    public byte[] DownloadLastMessageAsByteArray()
    {
      return GetLastMessage().ReadAllBytes();
    }

    public Stream DownloadMessageAsStream(long messageNumber)
    {
      return GetMessage(messageNumber).OpenRead();
    }

    public Stream DownloadFirstMessageAsStream()
    {
      return GetFirstMessage().OpenRead();
    }

    public Stream DownloadLastMessageAsStream()
    {
      return GetLastMessage().OpenRead();
    }

    public TOutput DownloadMessageAs<TOutput>(long messageNumber, Converter<Stream, TOutput> converter)
    {
      return GetMessage(messageNumber).ReadAs(converter);
    }

    public TResult DownloadMessageAs<T, TResult>(long messageNumber, Func<Stream, T, TResult> read, T arg)
    {
      return GetMessage(messageNumber).ReadAs(read, arg);
    }

    public TOutput DownloadFirstMessageAs<TOutput>(Converter<Stream, TOutput> converter)
    {
      return GetFirstMessage().ReadAs(converter);
    }

    public TResult DownloadFirstMessageAs<T, TResult>(Func<Stream, T, TResult> read, T arg)
    {
      return GetFirstMessage().ReadAs(read, arg);
    }

    public TOutput DownloadLastMessageAs<TOutput>(Converter<Stream, TOutput> converter)
    {
      return GetLastMessage().ReadAs(converter);
    }

    public TResult DownloadLastMessageAs<T, TResult>(Func<Stream, T, TResult> read, T arg)
    {
      return GetLastMessage().ReadAs(read, arg);
    }

    public IEnumerable<TOutput> DownloadAllMessagesAs<TOutput>(Converter<Stream, TOutput> converter)
    {
      foreach (var message in GetMessages(false)) {
        yield return message.ReadAs(converter);
      }
    }

    public IEnumerable<TResult> DownloadAllMessagesAs<T, TResult>(Func<Stream, T, TResult> read, T arg)
    {
      foreach (var message in GetMessages(false)) {
        yield return message.ReadAs(read, arg);
      }
    }

    public FileInfo DownloadMessageToFile(long messageNumber, string path)
    {
      var file = new FileInfo(path);

      GetMessage(messageNumber).Save(file, PopMessageInfo.EntireMessage);

      return file;
    }

    public FileInfo DownloadFirstMessageToFile(string path)
    {
      var file = new FileInfo(path);

      GetFirstMessage().Save(file, PopMessageInfo.EntireMessage);

      return file;
    }

    public FileInfo DownloadLastMessageToFile(string path)
    {
      var file = new FileInfo(path);

      GetLastMessage().Save(file, PopMessageInfo.EntireMessage);

      return file;
    }

    public FileInfo[] DownloadAllMessagesToDirectory(string directory)
    {
      if (directory == null)
        throw new ArgumentNullException("directory");
      if (directory.Length == 0)
        throw ExceptionUtils.CreateArgumentMustBeNonEmptyString("directory");

      ThrowIfNotConnected();

      if (!Directory.Exists(directory))
        Directory.CreateDirectory(directory);

      return DownloadAllMessagesToFiles(delegate(PopMessageInfo arg) {
        return Path.Combine(directory, string.Format("{0}.eml", arg.MessageNumber));
      });
    }

    public FileInfo[] DownloadAllMessagesToFiles(Func<PopMessageInfo, string> selectFileName)
    {
      if (selectFileName == null)
        throw new ArgumentNullException("selectFileName");

      return GetMessages(false).Select(delegate(PopMessageInfo message) {
        var file = new FileInfo(selectFileName(message));

        message.Save(file, PopMessageInfo.EntireMessage);

        return file;
      }).ToArray();
    }
  }
}

==> SimpleMailer-1.09.tar.bz2: SimpleMailer-1.09/core/Smdn.Net.Pop3.Client/Smdn.Net.Pop3.Client/PopClient.OperationsDownload.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2010-2014 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;
using System.Linq;
using System.IO;
using System.Text;

namespace Smdn.Net.Pop3.Client {
  partial class PopClient {
    public string DownloadMessageAsText(long messageNumber, Encoding encoding)
    {
      return GetMessage(messageNumber).ReadAllText(encoding);
    }

    public string DownloadFirstMessageAsText(Encoding encoding)
    {
      return GetFirstMessage().ReadAllText(encoding);
    }

    public string DownloadLastMessageAsText(Encoding encoding)
    {
      return GetLastMessage().ReadAllText(encoding);
    }

    public IEnumerable<string> DownloadAllMessagesAsText(Encoding encoding)
    {
      foreach (var message in GetMessages(false)) {
        yield return message.ReadAllText(encoding);
      }
    }

    public byte[] DownloadMessageAsByteArray(long messageNumber)
    {
      return GetMessage(messageNumber).ReadAllBytes();
    }

    public byte[] DownloadFirstMessageAsByteArray()
    {
      return GetFirstMessage().ReadAllBytes();
    }

    public byte[] DownloadLastMessageAsByteArray()
    {
      return GetLastMessage().ReadAllBytes();
    }

    public Stream DownloadMessageAsStream(long messageNumber)
    {
      return GetMessage(messageNumber).OpenRead();
    }

    public Stream DownloadFirstMessageAsStream()
    {
      return GetFirstMessage().OpenRead();
    }

    public Stream DownloadLastMessageAsStream()
    {
      return GetLastMessage().OpenRead();
    }

    public TResult DownloadMessageAs<TResult>(long messageNumber, Converter<Stream, TResult> converter)
    {
      return GetMessage(messageNumber).ReadAs(converter);
    }

    public TResult DownloadMessageAs<T, TResult>(long messageNumber, Func<Stream, T, TResult> read, T arg)
    {
      return GetMessage(messageNumber).ReadAs(read, arg);
    }

    public TResult DownloadFirstMessageAs<TResult>(Converter<Stream, TResult> converter)
    {
      return GetFirstMessage().ReadAs(converter);
    }

    public TResult DownloadFirstMessageAs<T, TResult>(Func<Stream, T, TResult> read, T arg)
    {
      return GetFirstMessage().ReadAs(read, arg);
    }

    public TResult DownloadLastMessageAs<TResult>(Converter<Stream, TResult> converter)
    {
      return GetLastMessage().ReadAs(converter);
    }

    public TResult DownloadLastMessageAs<T, TResult>(Func<Stream, T, TResult> read, T arg)
    {
      return GetLastMessage().ReadAs(read, arg);
    }

    public IEnumerable<TResult> DownloadAllMessagesAs<TResult>(Converter<Stream, TResult> converter)
    {
      foreach (var message in GetMessages(false)) {
        yield return message.ReadAs(converter);
      }
    }

    public IEnumerable<TResult> DownloadAllMessagesAs<T, TResult>(Func<Stream, T, TResult> read, T arg)
    {
      foreach (var message in GetMessages(false)) {
        yield return message.ReadAs(read, arg);
      }
    }

    public FileInfo DownloadMessageToFile(long messageNumber, string path)
    {
      var file = new FileInfo(path);

      GetMessage(messageNumber).Save(file, PopMessageInfo.EntireMessage);

      return file;
    }

    public FileInfo DownloadFirstMessageToFile(string path)
    {
      var file = new FileInfo(path);

      GetFirstMessage().Save(file, PopMessageInfo.EntireMessage);

      return file;
    }

    public FileInfo DownloadLastMessageToFile(string path)
    {
      var file = new FileInfo(path);

      GetLastMessage().Save(file, PopMessageInfo.EntireMessage);

      return file;
    }

    public FileInfo[] DownloadAllMessagesToDirectory(string directory)
    {
      if (directory == null)
        throw new ArgumentNullException("directory");
      if (directory.Length == 0)
        throw ExceptionUtils.CreateArgumentMustBeNonEmptyString("directory");

      ThrowIfNotConnected();

      if (!Directory.Exists(directory))
        Directory.CreateDirectory(directory);

      return DownloadAllMessagesToFiles(delegate(PopMessageInfo arg) {
        return Path.Combine(directory, string.Format("{0}.eml", arg.MessageNumber));
      });
    }

    public FileInfo[] DownloadAllMessagesToFiles(Func<PopMessageInfo, string> selectFileName)
    {
      if (selectFileName == null)
        throw new ArgumentNullException("selectFileName");

      return GetMessages(false).Select(delegate(PopMessageInfo message) {
        var file = new FileInfo(selectFileName(message));

        message.Save(file, PopMessageInfo.EntireMessage);

        return file;
      }).ToArray();
    }
  }
}
